.. _matrices:

Matrices and Matrix Arrays
==========================

``bewegung`` offers :ref:`matrices <matrix_single>` and :ref:`matrix arrays <matrix_array>`. Both of them work for 2x2 and 3x3 shapes. They are intended for simple tasks like rotations of :ref:`vectors <vector_single>` and :ref:`vector arrays <vector_array>`.

.. _matrix_single:

The ``Matrix`` Class
--------------------

.. autoclass:: bewegung.Matrix
    :members:

.. _matrix_array:

The ``MatrixArray`` Class
-------------------------

.. autoclass:: bewegung.MatrixArray
    :members:
